
.. py:currentmodule:: pythreejs

MeshPhysicalMaterial
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: MeshPhysicalMaterial()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.MeshStandardMaterial`.

    Three.js docs: https://threejs.org/docs/#api/materials/MeshPhysicalMaterial


    .. py:attribute:: clearCoat

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

    .. py:attribute:: clearCoatRoughness

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

    .. py:attribute:: defines

        .. sourcecode:: python

            Dict(default_value={"PHYSICAL":""}, allow_none=True).tag(sync=True)

    .. py:attribute:: reflectivity

        .. sourcecode:: python

            CFloat(0.5, allow_none=False).tag(sync=True)

